@@ -41,7 +41,7 @@
  */
 GdkPixbuf *
 GNUNET_FS_GTK_get_thumbnail_from_meta_data (
-  const struct GNUNET_CONTAINER_MetaData *meta);
+  const struct GNUNET_FS_MetaData *meta);
 
 
 /**
@@ -115,7 +115,7 @@ GNUNET_FS_GTK_dubious_meta_to_utf8 (enum EXTRACTOR_MetaFormat format,
  */
 char *
 GNUNET_FS_GTK_get_description_from_metadata (
-  const struct GNUNET_CONTAINER_MetaData *meta,
+  const struct GNUNET_FS_MetaData *meta,
   int *is_a_dup);
 
 
