@@ -403,7 +403,8 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
   lctx->nick = GNUNET_strdup (nick);
   /* again, show progress indicator, this should be fast though... */
   lctx->progress_dialog_builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_pseu_progress_dialog.glade",
+    GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                "gnunet_fs_gtk_pseu_progress_dialog.glade",
                                 lctx);
   lctx->progress_dialog =
     GTK_WIDGET (gtk_builder_get_object (lctx->progress_dialog_builder,
@@ -522,7 +523,9 @@ ask_for_nickname (struct PseuLookupContext *lctx)
 {
   /* setup the dialog and get the widgets we need most */
   lctx->nick_dialog_builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_enter_nick_dialog.glade", lctx);
+    GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                "gnunet_fs_gtk_enter_nick_dialog.glade",
+                                lctx);
   lctx->nick_dialog =
     GTK_WIDGET (gtk_builder_get_object (lctx->nick_dialog_builder,
                                         "GNUNET_GTK_enter_nick_window"));
@@ -692,7 +695,8 @@ GNUNET_FS_GTK_save_button_clicked_cb (GtkButton *button, gpointer user_data)
   {
     /* setup the dialog and get the widgets we need most */
     lctx->progress_dialog_builder =
-      GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_pseu_progress_dialog.glade",
+      GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                  "gnunet_fs_gtk_pseu_progress_dialog.glade",
                                   lctx);
     lctx->progress_dialog = GTK_WIDGET (
       gtk_builder_get_object (lctx->progress_dialog_builder,
