@@ -204,12 +204,12 @@ GNUNET_GTK_open_url_dialog_url_textview_buffer_changed_cb (
     uri = NULL;
   g_free (uris);
   gtk_widget_set_sensitive (GTK_WIDGET (gtk_builder_get_object (
-                              builder,
-                              "GNUNET_GTK_open_url_dialog_execute_button")),
+                                          builder,
+                                          "GNUNET_GTK_open_url_dialog_execute_button")),
                             (uri == NULL) ? FALSE : TRUE);
   if (uri != NULL)
     GNUNET_FS_uri_destroy (uri);
-  GNUNET_free_non_null (perr);
+  GNUNET_free (perr);
 }
 
 
@@ -232,7 +232,9 @@ GNUNET_GTK_main_menu_file_download_uri_activate_cb (GtkWidget *dummy,
   GtkComboBox *combo;
 
   builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_open_url_dialog.glade", NULL);
+    GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                "gnunet_fs_gtk_open_url_dialog.glade",
+                                NULL);
   if (NULL == builder)
   {
     GNUNET_break (0);
