@@ -1700,7 +1700,9 @@ scan_file_or_directory (struct MainPublishingDialogContext *ctx,
 
   /* setup the dialog and get the widgets we need most */
   adcc->progress_dialog_builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_progress_dialog.glade", adcc);
+    GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                "gnunet_fs_gtk_progress_dialog.glade",
+                                adcc);
   adcc->progress_dialog =
     GTK_WIDGET (gtk_builder_get_object (adcc->progress_dialog_builder,
                                         "GNUNET_FS_GTK_progress_dialog"));
@@ -1872,7 +1874,9 @@ GNUNET_GTK_master_publish_dialog_add_button_clicked_cb (GtkWidget *dummy,
   struct MainPublishingDialogContext *ctx = user_data;
 
   ctx->open_file_builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_publish_file_dialog.glade", ctx);
+    GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                "gnunet_fs_gtk_publish_file_dialog.glade",
+                                ctx);
   GNUNET_GTK_setup_expiration_year_adjustment (ctx->open_file_builder);
 
   /* FIXME-FEATURE: Use some kind of adjustable defaults instead of 1000, 0 and
@@ -1933,7 +1937,8 @@ GNUNET_GTK_master_publish_dialog_open_button_clicked_cb (GtkWidget *dummy,
   struct MainPublishingDialogContext *ctx = user_data;
 
   ctx->open_directory_builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_publish_directory_dialog.glade",
+    GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                "gnunet_fs_gtk_publish_directory_dialog.glade",
                                 ctx);
   GNUNET_GTK_setup_expiration_year_adjustment (ctx->open_directory_builder);
 
@@ -3002,7 +3007,9 @@ GNUNET_GTK_main_menu_file_publish_activate_cb (GtkWidget *dummy,
 
   ctx = GNUNET_new (struct MainPublishingDialogContext);
   ctx->builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_publish_dialog.glade", ctx);
+    GNUNET_GTK_get_new_builder (GNUNET_GTK_project_data (),
+                                "gnunet_fs_gtk_publish_dialog.glade",
+                                ctx);
   if (NULL == ctx->builder)
   {
     GNUNET_break (0);
