@@ -63,19 +63,24 @@ GNUNET_GTK_setup_nls (void);
 
 /**
  * Initialize GTK search path for icons.
+ *
+ * @param pd project data to use
  */
 void
-GNUNET_GTK_set_icon_search_path (void);
+GNUNET_GTK_set_icon_search_path (
+  const struct GNUNET_OS_ProjectData *pd);
 
 
 /**
  * Get the name of the directory where all of our package
  * data is stored ($PREFIX/share/)
  *
+ * @param pd project data to use
  * @return name of the data directory
  */
 const char *
-GNUNET_GTK_get_data_dir (void);
+GNUNET_GTK_get_data_dir (
+  const struct GNUNET_OS_ProjectData *pd);
 
 
 /**
@@ -88,7 +93,8 @@ GNUNET_GTK_get_data_dir (void);
  * @return a pointer to the dir path (to be freed by the caller)
  */
 char *
-GNUNET_GTK_installation_get_path (enum GNUNET_OS_InstallationPathKind dirkind);
+GNUNET_GTK_installation_get_path (
+  enum GNUNET_OS_InstallationPathKind dirkind);
 
 
 /* **************** Glade/Gtk helpers *************** */
@@ -97,6 +103,7 @@ GNUNET_GTK_installation_get_path (enum GNUNET_OS_InstallationPathKind dirkind);
  * Create an initialize a new builder based on the
  * GNUnet-GTK glade file.
  *
+ * @param pd project data to use
  * @param filename name of the resource file to load
  * @param user_data user_data to pass to signal handlers,
  *        use "NULL" to pass the GtkBuilder itself.
@@ -104,22 +111,25 @@ GNUNET_GTK_installation_get_path (enum GNUNET_OS_InstallationPathKind dirkind);
  * @return NULL on error
  */
 GtkBuilder *
-GNUNET_GTK_get_new_builder2 (const char *filename,
-                             void *user_data,
-                             GtkBuilderConnectFunc cb);
+GNUNET_GTK_get_new_builder2 (
+  const struct GNUNET_OS_ProjectData *pd,
+  const char *filename,
+  void *user_data,
+  GtkBuilderConnectFunc cb);
 
 
 /**
  * Create an initialize a new builder based on the GNUnet-GTK glade
  * file.
  *
+ * @param pd project data to use
  * @param filename name of the resource file to load
  * @param user_data user_data to pass to signal handlers,
  *        use "NULL" to pass the GtkBuilder itself.
  * @return NULL on error
  */
-#define GNUNET_GTK_get_new_builder(filename, user_data) \
-        GNUNET_GTK_get_new_builder2 (filename, user_data, NULL)
+#define GNUNET_GTK_get_new_builder(pd, filename, user_data)      \
+        GNUNET_GTK_get_new_builder2 (pd, filename, user_data, NULL)
 
 
 /**
@@ -128,10 +138,13 @@ GNUNET_GTK_get_new_builder2 (const char *filename,
  * "about_license_scroller" and "about_license_contents" being the
  * respective subdialogs.
  *
+ * @param pd project data to use
  * @param dialogfile name of the glade file containing the dialog
  */
 void
-GNUNET_GTK_display_about (const char *dialogfile);
+GNUNET_GTK_display_about (
+  const struct GNUNET_OS_ProjectData *pd,
+  const char *dialogfile);
 
 
 /**
@@ -247,15 +260,19 @@ GNUNET_GTK_main_loop_get_args (struct GNUNET_GTK_MainLoop *ml,
 
 
 /**
- * FIXME!
+ * Initialize a GtkBuilder for the main window and exit
+ * the main loop if this fails.
  *
- * @param ml FIXME
- * @param data FIXME
- * @return FIXME
+ * @param pd project data to use
+ * @param ml main loop contextual data
+ * @param data additional argument to pass to #GNUNET_GTK_get_new_builder()
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR on failure
  */
 int
-GNUNET_GTK_main_loop_build_window (struct GNUNET_GTK_MainLoop *ml,
-                                   gpointer data);
+GNUNET_GTK_main_loop_build_window (
+  const struct GNUNET_OS_ProjectData *pd,
+  struct GNUNET_GTK_MainLoop *ml,
+  gpointer data);
 
 
 /**
