@@ -47,7 +47,7 @@ struct GNUNET_GTK_MainLoop
   /**
    * Our configuration (includes defaults from gnunet-gtk/config.d/)
    */
-  struct GNUNET_CONFIGURATION_Handle *gnunet_gtk_cfg;
+  const struct GNUNET_CONFIGURATION_Handle *gnunet_gtk_cfg;
 
   /**
    * GNUnet configuration (includes defaults from gnunet/config.d/)
@@ -127,25 +127,14 @@ struct GNUNET_GTK_MainLoop
 };
 
 
-/**
- * Get the configuration.
- *
- * @param ml handle to the main loop
- * @return handle to the configuration, never NULL
- */
 const struct GNUNET_CONFIGURATION_Handle *
-GNUNET_GTK_main_loop_get_gnunet_configuration (struct GNUNET_GTK_MainLoop *ml)
+GNUNET_GTK_main_loop_get_gnunet_configuration (
+  struct GNUNET_GTK_MainLoop *ml)
 {
   return ml->gnunet_cfg;
 }
 
 
-/**
- * Get the configuration.
- *
- * @param ml handle to the main loop
- * @return handle to the configuration, never NULL
- */
 const struct GNUNET_CONFIGURATION_Handle *
 GNUNET_GTK_main_loop_get_gtk_configuration (
   struct GNUNET_GTK_MainLoop *ml)
@@ -154,11 +143,6 @@ GNUNET_GTK_main_loop_get_gtk_configuration (
 }
 
 
-/**
- * Trigger shutdown of the GUI and exit the main loop.
- *
- * @param ml handle to the main loop
- */
 void
 GNUNET_GTK_main_loop_quit (struct GNUNET_GTK_MainLoop *ml)
 {
@@ -172,12 +156,6 @@ GNUNET_GTK_main_loop_quit (struct GNUNET_GTK_MainLoop *ml)
 }
 
 
-/**
- * Get the builder from the main window.
- *
- * @param ml handle to the main loop
- * @return NULL on error, otherwise the builder
- */
 GtkBuilder *
 GNUNET_GTK_main_loop_get_builder (struct GNUNET_GTK_MainLoop *ml)
 {
@@ -186,11 +164,16 @@ GNUNET_GTK_main_loop_get_builder (struct GNUNET_GTK_MainLoop *ml)
 
 
 int
-GNUNET_GTK_main_loop_build_window (struct GNUNET_GTK_MainLoop *ml,
-                                   gpointer data)
+GNUNET_GTK_main_loop_build_window (
+  const struct GNUNET_OS_ProjectData *pd,
+  struct GNUNET_GTK_MainLoop *ml,
+  gpointer data)
 {
-  ml->builder = GNUNET_GTK_get_new_builder (ml->main_window_file, data);
-  if (ml->builder == NULL)
+  GNUNET_GTK_set_icon_search_path (pd);
+  ml->builder = GNUNET_GTK_get_new_builder (pd,
+                                            ml->main_window_file,
+                                            data);
+  if (NULL == ml->builder)
   {
     GNUNET_GTK_main_loop_quit (ml);
     return GNUNET_SYSERR;
@@ -199,12 +182,6 @@ GNUNET_GTK_main_loop_build_window (struct GNUNET_GTK_MainLoop *ml,
 }
 
 
-/**
- * Obtain the name of the configuration file that is being used.
- *
- * @param ml handle to the main loop
- * @return name of configuration file
- */
 const char *
 GNUNET_GTK_main_loop_get_gnunet_configuration_file (
   struct GNUNET_GTK_MainLoop *ml)
@@ -213,12 +190,6 @@ GNUNET_GTK_main_loop_get_gnunet_configuration_file (
 }
 
 
-/**
- * Obtain the name of the configuration file that is being used.
- *
- * @param ml handle to the main loop
- * @return name of configuration file
- */
 const char *
 GNUNET_GTK_main_loop_get_gtk_configuration_file (
   struct GNUNET_GTK_MainLoop *ml)
@@ -227,32 +198,20 @@ GNUNET_GTK_main_loop_get_gtk_configuration_file (
 }
 
 
-/**
- * Get an object from the main window.
- *
- * @param ml handle to the main loop
- * @param name name of the object
- * @return NULL on error, otherwise the object
- */
 GObject *
 GNUNET_GTK_main_loop_get_object (struct GNUNET_GTK_MainLoop *ml,
                                  const char *name)
 {
-  return gtk_builder_get_object (ml->builder, name);
+  return gtk_builder_get_object (ml->builder,
+                                 name);
 }
 
 
-/**
- * Get remaining command line arguments.
- *
- * @param ml handle to the main loop
- * @param argc set to argument count
- * @param argv set to argument vector
- */
 void
-GNUNET_GTK_main_loop_get_args (struct GNUNET_GTK_MainLoop *ml,
-                               int *argc,
-                               char *const **argv)
+GNUNET_GTK_main_loop_get_args (
+  struct GNUNET_GTK_MainLoop *ml,
+  int *argc,
+  char *const **argv)
 {
   *argc = ml->argc;
   *argv = ml->argv;
@@ -280,12 +239,16 @@ dispatch_gtk_task (void *cls)
  * @param new_size desired size of the cached poll array
  */
 static void
-resize_cached_poll_array (struct GNUNET_GTK_MainLoop *ml, guint new_size)
+resize_cached_poll_array (struct GNUNET_GTK_MainLoop *ml,
+                          guint new_size)
 {
   if (NULL == ml->cached_poll_array)
-    ml->cached_poll_array = g_new (GPollFD, new_size);
+    ml->cached_poll_array = g_new (GPollFD,
+                                   new_size);
   else
-    ml->cached_poll_array = g_renew (GPollFD, ml->cached_poll_array, new_size);
+    ml->cached_poll_array = g_renew (GPollFD,
+                                     ml->cached_poll_array,
+                                     new_size);
   ml->cached_poll_array_size = new_size;
 }
 
@@ -483,94 +446,38 @@ gnunet_gtk_select (void *cls,
  *
  * @param cls the `struct GNUNET_GTK_MainLoop`
  * @param args leftover command line arguments (go to gtk)
- * @param cfgfile name of the gnunet-gtk configuration file
- * @param cfg handle to the configuration
+ * @param gnunet_gtk_cfgfile name of the gnunet-gtk configuration file
+ * @param gnunet_gtk_cfg handle to the configuration
  */
 static void
 run_main_loop (void *cls,
                char *const *args,
-               const char *cfgfile,
-               const struct GNUNET_CONFIGURATION_Handle *cfg)
+               const char *gnunet_gtk_cfgfile,
+               const struct GNUNET_CONFIGURATION_Handle *gnunet_gtk_cfg)
 {
   struct GNUNET_GTK_MainLoop *ml = cls;
-  const struct GNUNET_OS_ProjectData *pd;
-  struct GNUNET_CONFIGURATION_Handle *gcfg;
-  char *baseconfig;
-  char *ipath2;
-  char *ipath;
+  const struct GNUNET_OS_ProjectData *gnunet_pd
+    = GNUNET_OS_project_data_gnunet ();
   int argc;
 
   /* command-line processing for Gtk arguments */
-  pd = GNUNET_CONFIGURATION_get_project_data (cfg);
   argc = 0;
-  while (args[argc] != NULL)
+  while (NULL != args[argc])
     argc++;
   gtk_init (&argc, (char ***) &args);
-  gcfg = GNUNET_CONFIGURATION_create (pd);
+  ml->argc = argc;
+  ml->argv = args;
 
-  if (NULL == (ipath = GNUNET_OS_installation_get_path (
-                 pd,
-                 GNUNET_OS_IPK_DATADIR)))
-  {
-    GNUNET_break (0);
-    return;
-  }
-  GNUNET_asprintf (&baseconfig,
-                   "%s%s",
-                   ipath,
-                   "config.d");
-  (void) GNUNET_CONFIGURATION_load_from (gcfg,
-                                         baseconfig);
-  GNUNET_free (baseconfig);
-  if (NULL ==
-      (ipath2 = GNUNET_OS_installation_get_path (pd,
-                                                 GNUNET_OS_IPK_DATADIR)))
-  {
-    GNUNET_break (0);
-    return;
-  }
-  if (0 != strcmp (ipath, ipath2))
-  {
-    GNUNET_asprintf (&baseconfig,
-                     "%s%s",
-                     ipath2,
-                     "config.d");
-    if (GNUNET_YES ==
-        GNUNET_DISK_directory_test (baseconfig,
-                                    GNUNET_YES))
-      (void) GNUNET_CONFIGURATION_load_from (gcfg,
-                                             baseconfig);
-    GNUNET_free (baseconfig);
-  }
-  GNUNET_free (ipath2);
-  GNUNET_free (ipath);
-
-  if (GNUNET_YES == GNUNET_DISK_file_test (cfgfile))
-    (void) GNUNET_CONFIGURATION_parse (gcfg,
-                                       cfgfile);
+  if (NULL != gnunet_gtk_cfgfile)
+    ml->gnunet_gtk_cfgfile = GNUNET_strdup (gnunet_gtk_cfgfile);
+  ml->gnunet_gtk_cfg = gnunet_gtk_cfg;
   ml->rs = GNUNET_NETWORK_fdset_create ();
   ml->ws = GNUNET_NETWORK_fdset_create ();
-  ml->gml = g_main_loop_new (NULL, TRUE);
+  ml->gml = g_main_loop_new (NULL,
+                             TRUE);
   ml->gmc = g_main_loop_get_context (ml->gml);
-  ml->gnunet_gtk_cfg = gcfg;
-  if (NULL == ml->gnunet_cfgfile)
-  {
-    const char *xdg = getenv ("XDG_CONFIG_HOME");
-
-    if (NULL != xdg)
-      GNUNET_asprintf (
-        &ml->gnunet_cfgfile,
-        "%s%s%s",
-        xdg,
-        DIR_SEPARATOR_STR,
-        GNUNET_CONFIGURATION_get_project_data (cfg)->config_file);
-    else
-      ml->gnunet_cfgfile
-        = GNUNET_strdup (
-            GNUNET_CONFIGURATION_get_project_data (cfg)->user_config_file);
-  }
   ml->gnunet_cfg
-    = GNUNET_CONFIGURATION_create (GNUNET_OS_project_data_gnunet ());
+    = GNUNET_CONFIGURATION_create (gnunet_pd);
   if (GNUNET_OK !=
       GNUNET_CONFIGURATION_load (ml->gnunet_cfg,
                                  ml->gnunet_cfgfile))
@@ -579,13 +486,6 @@ run_main_loop (void *cls,
     GNUNET_SCHEDULER_shutdown ();
     return;
   }
-  /* FIXME: add command-line option to allow parsing
-     a configuration file for gnunet_cfg as well! */
-
-  if (NULL != cfgfile)
-    ml->gnunet_gtk_cfgfile = GNUNET_strdup (cfgfile);
-  ml->argc = argc;
-  ml->argv = args;
 
   /* start the Gtk event loop */
   GNUNET_assert (g_main_context_acquire (ml->gmc));
@@ -670,11 +570,7 @@ GNUNET_GTK_main_loop_start (
     GNUNET_CONFIGURATION_destroy (ml.gnunet_cfg);
     ml.gnunet_cfg = NULL;
   }
-  if (NULL != ml.gnunet_gtk_cfg)
-  {
-    GNUNET_CONFIGURATION_destroy (ml.gnunet_gtk_cfg);
-    ml.gnunet_gtk_cfg = NULL;
-  }
+  ml.gnunet_gtk_cfg = NULL;
   GNUNET_free (ml.gnunet_cfgfile);
   GNUNET_free (ml.gnunet_gtk_cfgfile);
   return ret;
