@@ -40,15 +40,21 @@ duc_dummy (void *cls, int delta)
  * Test if the configuration works for the given plugin.
  *
  * @param name name of the plugin to check
- * @return GNUNET_OK on success, GNUNET_SYSERR if the config is wrong
+ * @return #GNUNET_OK on success, #GNUNET_SYSERR if the config is wrong
  */
 static int
 test_config (const char *name)
 {
-  struct GNUNET_DATASTORE_PluginEnvironment env = {cfg, &duc_dummy, NULL};
+  struct GNUNET_DATASTORE_PluginEnvironment env = {
+    cfg,
+    &duc_dummy,
+    NULL
+  };
   void *ret;
 
-  ret = GNUNET_PLUGIN_load (name, &env);
+  ret = GNUNET_PLUGIN_load (GNUNET_OS_project_data_gnunet (),
+                            name,
+                            &env);
   if (NULL == ret)
     return GNUNET_SYSERR;
   GNUNET_PLUGIN_unload (name, ret);
