@@ -157,7 +157,8 @@ test_hostlist_daemon (TestHostlistDaemonCallback callback, void *cls)
   ctx->callback = callback;
   ctx->callback_cls = cls;
   ctx->found = GNUNET_NO;
-  binary = GNUNET_OS_get_libexec_binary_path ("gnunet-daemon-hostlist");
+  binary = GNUNET_OS_get_libexec_binary_path (GNUNET_OS_project_data_gnunet (),
+                                              "gnunet-daemon-hostlist");
   ctx->cmd = GNUNET_OS_command_run (&process_hostlist_daemon_output,
                                     ctx,
                                     CMD_TIMEOUT,
