@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010, 2011 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2010, 2011 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -31,12 +31,13 @@
  * transport configuration.
  *
  * @param section_name section with the port numbers
- * @param is_tcp GNUNET_YES for TCP, GNUNET_NO for UDP
+ * @param proto IPPROTO_TCP or IPPROTO_UDP
  * @param success_image image to show on success
  * @param failure_image image to show on failure
  */
 void
-GNUNET_setup_transport_test (const char *section_name, int is_tcp,
+GNUNET_setup_transport_test (const char *section_name,
+                             int proto,
                              const char *success_image,
                              const char *failure_image);
 
