@@ -32,10 +32,11 @@
  * This displays an about window
  */
 void
-GNUNET_STATISTICS_GTK_main_menu_help_about_activate_cb (GtkWidget * dummy,
+GNUNET_STATISTICS_GTK_main_menu_help_about_activate_cb (GtkWidget *dummy,
                                                         gpointer data)
 {
-  GNUNET_GTK_display_about ("gnunet_statistics_gtk_about_window.glade");
+  GNUNET_GTK_display_about (GNUNET_GTK_project_data (),
+                            "gnunet_statistics_gtk_about_window.glade");
 }
 
 
